==> cdk-customresources-1.14.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/customresources/AwsCustomResourceProps.java <==
package software.amazon.awscdk.customresources;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-22T08:26:11.640Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AwsCustomResourceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The AWS SDK call to make when the resource is created. At least onCreate, onUpdate or onDelete must be specified.
     * 
     * Default: the call when the resource is updated
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnCreate();

    /**
     * The AWS SDK call to make when the resource is deleted.
     * 
     * Default: no call
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnDelete();

    /**
     * The AWS SDK call to make when the resource is updated.
     * 
     * Default: no call
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnUpdate();

    /**
     * The IAM policy statements to allow the different calls.
     * 
     * Use only if
     * resource restriction is needed.
     * 
     * Default: extract the permissions from the calls
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> getPolicyStatements();

    /**
     * @return a {@link Builder} of {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private software.amazon.awscdk.customresources.AwsSdkCall onCreate;
        private software.amazon.awscdk.customresources.AwsSdkCall onDelete;
        private software.amazon.awscdk.customresources.AwsSdkCall onUpdate;
        private java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements;

        /**
         * Sets the value of OnCreate
         * @param onCreate The AWS SDK call to make when the resource is created. At least onCreate, onUpdate or onDelete must be specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onCreate(software.amazon.awscdk.customresources.AwsSdkCall onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of OnDelete
         * @param onDelete The AWS SDK call to make when the resource is deleted.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onDelete(software.amazon.awscdk.customresources.AwsSdkCall onDelete) {
            this.onDelete = onDelete;
            return this;
        }

        /**
         * Sets the value of OnUpdate
         * @param onUpdate The AWS SDK call to make when the resource is updated.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onUpdate(software.amazon.awscdk.customresources.AwsSdkCall onUpdate) {
            this.onUpdate = onUpdate;
            return this;
        }

        /**
         * Sets the value of PolicyStatements
         * @param policyStatements The IAM policy statements to allow the different calls.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder policyStatements(java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements) {
            this.policyStatements = policyStatements;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AwsCustomResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public AwsCustomResourceProps build() {
            return new Jsii$Proxy(onCreate, onDelete, onUpdate, policyStatements);
        }
    }

    /**
     * An implementation for {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AwsCustomResourceProps {
        private final software.amazon.awscdk.customresources.AwsSdkCall onCreate;
        private final software.amazon.awscdk.customresources.AwsSdkCall onDelete;
        private final software.amazon.awscdk.customresources.AwsSdkCall onUpdate;
        private final java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.onCreate = this.jsiiGet("onCreate", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.onDelete = this.jsiiGet("onDelete", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.onUpdate = this.jsiiGet("onUpdate", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.policyStatements = this.jsiiGet("policyStatements", java.util.List.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.customresources.AwsSdkCall onCreate, software.amazon.awscdk.customresources.AwsSdkCall onDelete, software.amazon.awscdk.customresources.AwsSdkCall onUpdate, java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.onCreate = onCreate;
            this.onDelete = onDelete;
            this.onUpdate = onUpdate;
            this.policyStatements = policyStatements;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnCreate() {
            return this.onCreate;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnDelete() {
            return this.onDelete;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnUpdate() {
            return this.onUpdate;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> getPolicyStatements() {
            return this.policyStatements;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getOnCreate() != null) {
                obj.set("onCreate", om.valueToTree(this.getOnCreate()));
            }
            if (this.getOnDelete() != null) {
                obj.set("onDelete", om.valueToTree(this.getOnDelete()));
            }
            if (this.getOnUpdate() != null) {
                obj.set("onUpdate", om.valueToTree(this.getOnUpdate()));
            }
            if (this.getPolicyStatements() != null) {
                obj.set("policyStatements", om.valueToTree(this.getPolicyStatements()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AwsCustomResourceProps.Jsii$Proxy that = (AwsCustomResourceProps.Jsii$Proxy) o;

            if (this.onCreate != null ? !this.onCreate.equals(that.onCreate) : that.onCreate != null) return false;
            if (this.onDelete != null ? !this.onDelete.equals(that.onDelete) : that.onDelete != null) return false;
            if (this.onUpdate != null ? !this.onUpdate.equals(that.onUpdate) : that.onUpdate != null) return false;
            return this.policyStatements != null ? this.policyStatements.equals(that.policyStatements) : that.policyStatements == null;
        }

        @Override
        public int hashCode() {
            int result = this.onCreate != null ? this.onCreate.hashCode() : 0;
            result = 31 * result + (this.onDelete != null ? this.onDelete.hashCode() : 0);
            result = 31 * result + (this.onUpdate != null ? this.onUpdate.hashCode() : 0);
            result = 31 * result + (this.policyStatements != null ? this.policyStatements.hashCode() : 0);
            return result;
        }
    }
}

==> cdk-customresources-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/customresources/AwsCustomResourceProps.java <==
package software.amazon.awscdk.customresources;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:26:09.416Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AwsCustomResourceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The AWS SDK call to make when the resource is created. At least onCreate, onUpdate or onDelete must be specified.
     * 
     * Default: the call when the resource is updated
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnCreate();

    /**
     * The AWS SDK call to make when the resource is deleted.
     * 
     * Default: no call
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnDelete();

    /**
     * The AWS SDK call to make when the resource is updated.
     * 
     * Default: no call
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.customresources.AwsSdkCall getOnUpdate();

    /**
     * The IAM policy statements to allow the different calls.
     * 
     * Use only if
     * resource restriction is needed.
     * 
     * Default: extract the permissions from the calls
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> getPolicyStatements();

    /**
     * The timeout for the Lambda function implementing this custom resource.
     * 
     * Default: Duration.seconds(30)
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.core.Duration getTimeout();

    /**
     * @return a {@link Builder} of {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private software.amazon.awscdk.customresources.AwsSdkCall onCreate;
        private software.amazon.awscdk.customresources.AwsSdkCall onDelete;
        private software.amazon.awscdk.customresources.AwsSdkCall onUpdate;
        private java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements;
        private software.amazon.awscdk.core.Duration timeout;

        /**
         * Sets the value of OnCreate
         * @param onCreate The AWS SDK call to make when the resource is created. At least onCreate, onUpdate or onDelete must be specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onCreate(software.amazon.awscdk.customresources.AwsSdkCall onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of OnDelete
         * @param onDelete The AWS SDK call to make when the resource is deleted.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onDelete(software.amazon.awscdk.customresources.AwsSdkCall onDelete) {
            this.onDelete = onDelete;
            return this;
        }

        /**
         * Sets the value of OnUpdate
         * @param onUpdate The AWS SDK call to make when the resource is updated.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder onUpdate(software.amazon.awscdk.customresources.AwsSdkCall onUpdate) {
            this.onUpdate = onUpdate;
            return this;
        }

        /**
         * Sets the value of PolicyStatements
         * @param policyStatements The IAM policy statements to allow the different calls.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder policyStatements(java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements) {
            this.policyStatements = policyStatements;
            return this;
        }

        /**
         * Sets the value of Timeout
         * @param timeout The timeout for the Lambda function implementing this custom resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder timeout(software.amazon.awscdk.core.Duration timeout) {
            this.timeout = timeout;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AwsCustomResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public AwsCustomResourceProps build() {
            return new Jsii$Proxy(onCreate, onDelete, onUpdate, policyStatements, timeout);
        }
    }

    /**
     * An implementation for {@link AwsCustomResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AwsCustomResourceProps {
        private final software.amazon.awscdk.customresources.AwsSdkCall onCreate;
        private final software.amazon.awscdk.customresources.AwsSdkCall onDelete;
        private final software.amazon.awscdk.customresources.AwsSdkCall onUpdate;
        private final java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements;
        private final software.amazon.awscdk.core.Duration timeout;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.onCreate = this.jsiiGet("onCreate", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.onDelete = this.jsiiGet("onDelete", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.onUpdate = this.jsiiGet("onUpdate", software.amazon.awscdk.customresources.AwsSdkCall.class);
            this.policyStatements = this.jsiiGet("policyStatements", java.util.List.class);
            this.timeout = this.jsiiGet("timeout", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.customresources.AwsSdkCall onCreate, software.amazon.awscdk.customresources.AwsSdkCall onDelete, software.amazon.awscdk.customresources.AwsSdkCall onUpdate, java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> policyStatements, software.amazon.awscdk.core.Duration timeout) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.onCreate = onCreate;
            this.onDelete = onDelete;
            this.onUpdate = onUpdate;
            this.policyStatements = policyStatements;
            this.timeout = timeout;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnCreate() {
            return this.onCreate;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnDelete() {
            return this.onDelete;
        }

        @Override
        public software.amazon.awscdk.customresources.AwsSdkCall getOnUpdate() {
            return this.onUpdate;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.iam.PolicyStatement> getPolicyStatements() {
            return this.policyStatements;
        }

        @Override
        public software.amazon.awscdk.core.Duration getTimeout() {
            return this.timeout;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getOnCreate() != null) {
                obj.set("onCreate", om.valueToTree(this.getOnCreate()));
            }
            if (this.getOnDelete() != null) {
                obj.set("onDelete", om.valueToTree(this.getOnDelete()));
            }
            if (this.getOnUpdate() != null) {
                obj.set("onUpdate", om.valueToTree(this.getOnUpdate()));
            }
            if (this.getPolicyStatements() != null) {
                obj.set("policyStatements", om.valueToTree(this.getPolicyStatements()));
            }
            if (this.getTimeout() != null) {
                obj.set("timeout", om.valueToTree(this.getTimeout()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AwsCustomResourceProps.Jsii$Proxy that = (AwsCustomResourceProps.Jsii$Proxy) o;

            if (this.onCreate != null ? !this.onCreate.equals(that.onCreate) : that.onCreate != null) return false;
            if (this.onDelete != null ? !this.onDelete.equals(that.onDelete) : that.onDelete != null) return false;
            if (this.onUpdate != null ? !this.onUpdate.equals(that.onUpdate) : that.onUpdate != null) return false;
            if (this.policyStatements != null ? !this.policyStatements.equals(that.policyStatements) : that.policyStatements != null) return false;
            return this.timeout != null ? this.timeout.equals(that.timeout) : that.timeout == null;
        }

        @Override
        public int hashCode() {
            int result = this.onCreate != null ? this.onCreate.hashCode() : 0;
            result = 31 * result + (this.onDelete != null ? this.onDelete.hashCode() : 0);
            result = 31 * result + (this.onUpdate != null ? this.onUpdate.hashCode() : 0);
            result = 31 * result + (this.policyStatements != null ? this.policyStatements.hashCode() : 0);
            result = 31 * result + (this.timeout != null ? this.timeout.hashCode() : 0);
            return result;
        }
    }
}
